translate.convert.po2xliff

Package translate :: Package convert :: Module po2xliff |
[hide private]
[frames] | no frames]

# Module po2xliff

source code

convert Gettext PO localization files to XLIFF localization files

see: http://translate.sourceforge.net/wiki/toolkit/po2xliff for examples and usage instructions

Classes | [hide private]
| po2xliff

Functions | [hide private]
convertpo(inputfile, outputfile, templatefile) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: po, poxliff